==> ddd-4-java-0.4.0-sources.jar: org/fuin/ddd4j/ddd/DomainEventExpectedEntityIdPath.java <==
/**
 * Copyright (C) 2015 Michael Schnell. All rights reserved. 
 * http://www.fuin.org/
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 3 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 */
package org.fuin.ddd4j.ddd;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import javax.validation.Constraint;
import javax.validation.Payload;

//CHECKSTYLE:OFF
/**
 * The entity identifier path of a domain event should contain a defined order and type of entries.
 */
@Target({ ElementType.TYPE })
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = { DomainEventExpectedEntityIdPathValidator.class })
@Documented
public @interface DomainEventExpectedEntityIdPath {

    String message() default "{org.fuin.ddd4j.ddd.DomainEventExpectedEntityIdPath.message}";

    /**
     * Expected ID types.
     * 
     * @return Ordered list of expected types.
     */
    Class<? extends EntityId>[] value();

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};

}
// CHECKSTYLE:ON

==> ddd-4-java-0.5.0-sources.jar: org/fuin/ddd4j/ddd/DomainEventExpectedEntityIdPath.java <==
/**
 * Copyright (C) 2015 Michael Schnell. All rights reserved. 
 * http://www.fuin.org/
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 3 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 */
package org.fuin.ddd4j.ddd;

import jakarta.validation.Constraint;
import jakarta.validation.Payload;

import java.lang.annotation.*;

//CHECKSTYLE:OFF
/**
 * The entity identifier path of a domain event should contain a defined order and type of entries.
 */
@Target({ ElementType.TYPE })
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = { DomainEventExpectedEntityIdPathValidator.class })
@Documented
public @interface DomainEventExpectedEntityIdPath {

    String message() default "{org.fuin.ddd4j.ddd.DomainEventExpectedEntityIdPath.message}";

    /**
     * Expected ID types.
     * 
     * @return Ordered list of expected types.
     */
    Class<? extends EntityId>[] value();

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};

}
// CHECKSTYLE:ON
